@@ -23,20 +23,26 @@ class UnbindAliasRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'Push', '2016-08-01', 'UnbindAlias')
 
-	def get_AppKey(self):
-		return self.get_query_params().get('AppKey')
-
-	def set_AppKey(self,AppKey):
-		self.add_query_param('AppKey',AppKey)
-
 	def get_AliasName(self):
 		return self.get_query_params().get('AliasName')
 
 	def set_AliasName(self,AliasName):
 		self.add_query_param('AliasName',AliasName)
 
+	def get_AppKey(self):
+		return self.get_query_params().get('AppKey')
+
+	def set_AppKey(self,AppKey):
+		self.add_query_param('AppKey',AppKey)
+
 	def get_DeviceId(self):
 		return self.get_query_params().get('DeviceId')
 
 	def set_DeviceId(self,DeviceId):
-		self.add_query_param('DeviceId',DeviceId)
\ No newline at end of file
+		self.add_query_param('DeviceId',DeviceId)
+
+	def get_UnbindAll(self):
+		return self.get_query_params().get('UnbindAll')
+
+	def set_UnbindAll(self,UnbindAll):
+		self.add_query_param('UnbindAll',UnbindAll)
\ No newline at end of file
